@@ -8,14 +8,16 @@ This plugin allows you to embed `Gists`_ into your posts.
 .. _Gists: https://gist.github.com/
 
 """
-import logging
+from __future__ import unicode_literals
 import hashlib
+import logging
 import os
 import re
 
 
 logger = logging.getLogger(__name__)
-gist_regex = re.compile(r'(<p>\[gist:id\=([0-9a-fA-F]+)(,file\=([^\]]+))?\]</p>)')
+gist_regex = re.compile(
+    r'(<p>\[gist:id\=([0-9a-fA-F]+)(,file\=([^\]]+))?\]</p>)')
 gist_template = """<div class="gist">
     <script src='{{script_url}}'></script>
     <noscript>
@@ -24,10 +26,6 @@ gist_template = """<div class="gist">
 </div>"""
 
 
-def html_output(script_url, code):
-    return ""
-
-
 def gist_url(gist_id, filename=None):
     url = "https://gist.github.com/raw/{}".format(gist_id)
     if filename is not None:
@@ -44,9 +42,9 @@ def script_url(gist_id, filename=None):
 
 def cache_filename(base, gist_id, filename=None):
     h = hashlib.md5()
-    h.update(gist_id)
+    h.update(str(gist_id).encode())
     if filename is not None:
-        h.update(filename)
+        h.update(filename.encode())
     return os.path.join(base, '{}.cache'.format(h.hexdigest()))
 
 
@@ -54,13 +52,13 @@ def get_cache(base, gist_id, filename=None):
     cache_file = cache_filename(base, gist_id, filename)
     if not os.path.exists(cache_file):
         return None
-    with open(cache_file, 'r') as f:
-        return f.read()
+    with open(cache_file, 'rb') as f:
+        return f.read().decode()
 
 
 def set_cache(base, gist_id, body, filename=None):
-    with open(cache_filename(base, gist_id, filename), 'w') as f:
-        f.write(body)
+    with open(cache_filename(base, gist_id, filename), 'wb') as f:
+        f.write(body.encode())
 
 
 def fetch_gist(gist_id, filename=None):
@@ -84,7 +82,7 @@ def setup_gist(pelican):
 
     pelican.settings.setdefault('GIST_CACHE_ENABLED', True)
     pelican.settings.setdefault('GIST_CACHE_LOCATION',
-        '/tmp/gist-cache')
+                                '/tmp/gist-cache')
 
     # Make sure the gist cache directory exists
     cache_base = pelican.settings.get('GIST_CACHE_LOCATION')
@@ -116,20 +114,20 @@ def replace_gist_tags(generator):
 
             # Fetch the gist
             if not body:
-                logger.info('[gist]:   Gist did not exist in cache, fetching...')
+                logger.info('[gist]: Gist did not exist in cache, fetching...')
                 body = fetch_gist(gist_id, filename)
 
                 if should_cache:
-                    logger.info('[gist]:   Saving gist to cache...')
+                    logger.info('[gist]: Saving gist to cache...')
                     set_cache(cache_location, gist_id, body, filename)
             else:
-                logger.info('[gist]:   Found gist in cache.')
+                logger.info('[gist]: Found gist in cache.')
 
             # Create a context to render with
             context = generator.context.copy()
             context.update({
-                'script_url': unicode(script_url(gist_id, filename), 'utf-8'),
-                'code': unicode(body, 'utf-8'),
+                'script_url': script_url(gist_id, filename),
+                'code': body,
             })
 
             # Render the template
